summaryrefslogtreecommitdiffstats
path: root/kwin/clients/quartz/config/config.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/clients/quartz/config/config.cpp')
-rw-r--r--kwin/clients/quartz/config/config.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kwin/clients/quartz/config/config.cpp b/kwin/clients/quartz/config/config.cpp
index d15eb4da1..c4c8e5cba 100644
--- a/kwin/clients/quartz/config/config.cpp
+++ b/kwin/clients/quartz/config/config.cpp
@@ -23,18 +23,18 @@ extern "C"
/* NOTE:
* 'conf' is a pointer to the kwindecoration modules open kwin config,
* and is by default set to the "Style" group.
*
* 'parent' is the parent of the TQObject, which is a VBox inside the
- * Configure tab in kwindecoration
+ * Configure tab in twindecoration
*/
QuartzConfig::QuartzConfig( KConfig* conf, TQWidget* parent )
: TQObject( parent )
{
- quartzConfig = new KConfig("kwinquartzrc");
- KGlobal::locale()->insertCatalogue("kwin_clients");
+ quartzConfig = new KConfig("twinquartzrc");
+ KGlobal::locale()->insertCatalogue("twin_clients");
gb = new TQVBox( parent );
cbColorBorder = new TQCheckBox(
i18n("Draw window frames using &titlebar colors"), gb );
@@ -52,7 +52,7 @@ QuartzConfig::QuartzConfig( KConfig* conf, TQWidget* parent )
connect( cbColorBorder, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSelectionChanged()) );
connect( cbExtraSmall, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSelectionChanged()) );
- // Make the widgets visible in kwindecoration
+ // Make the widgets visible in twindecoration
gb->show();
}
@@ -70,8 +70,8 @@ void QuartzConfig::slotSelectionChanged()
}
-// Loads the configurable options from the kwinrc config file
-// It is passed the open config from kwindecoration to improve efficiency
+// Loads the configurable options from the twinrc config file
+// It is passed the open config from twindecoration to improve efficiency
void QuartzConfig::load( KConfig* /*conf*/ )
{
quartzConfig->setGroup("General");
@@ -82,7 +82,7 @@ void QuartzConfig::load( KConfig* /*conf*/ )
}
-// Saves the configurable options to the kwinrc config file
+// Saves the configurable options to the twinrc config file
void QuartzConfig::save( KConfig* /*conf*/ )
{
quartzConfig->setGroup("General");
@@ -23,18 +23,18 @@ extern "C"
/* NOTE:
- * 'conf' is a pointer to the kwindecoration modules open kwin config,
+ * 'conf' is a pointer to the twindecoration modules open twin config,
* and is by default set to the "Style" group.
*